@@ -7,8 +7,9 @@ use Filter::signatures;
 no warnings 'experimental::signatures';
 use feature 'signatures';
 
-use vars qw($VERSION);
-$VERSION = '0.07';
+our $VERSION = '0.08';
+
+with 'Future::HTTP::Handler';
 
 has ua => (
     is => 'lazy',
@@ -77,12 +78,8 @@ sub _request($self, $method, $url, %options) {
     my $res = Future::Mojo->new();
     $_tx = $self->ua->start($_tx, sub( $ua, $tx ) {
         my( $body, $headers ) = $self->_ae_from_mojolicious( $tx );
-    
-        if( $headers->{Status} =~ /^2../ ) {
-            $res->done($body, $headers);
-        } else {
-            $res->fail('error when connecting', $headers);
-        }
+        
+        $self->http_response_received( $res, $body, $headers );
     });
     
     $res
@@ -216,7 +213,7 @@ Max Maischein C<corion@cpan.org>
 
 =head1 COPYRIGHT (c)
 
-Copyright 2016 by Max Maischein C<corion@cpan.org>.
+Copyright 2016-2017 by Max Maischein C<corion@cpan.org>.
 
 =head1 LICENSE
 
